==> hudder-8.5.1-sources.jar: io/github/ngspace/hudder/data_management/BooleanData.java <==
package io.github.ngspace.hudder.data_management;

import static io.github.ngspace.hudder.data_management.Advanced.isKeyHeld;

import io.github.ngspace.hudder.Hudder;
import io.github.ngspace.hudder.main.config.HudderConfig;
import net.minecraft.class_1308;
import net.minecraft.class_1492;
import net.minecraft.class_1496;
import net.minecraft.class_1934;
import net.minecraft.class_2919;
import net.minecraft.class_310;
import net.minecraft.class_408;
import net.minecraft.class_4184;
import net.minecraft.class_476;
import net.minecraft.class_479;
import net.minecraft.class_481;
import net.minecraft.class_490;
import net.minecraft.class_746;

public class BooleanData {private BooleanData(){}
	public static Boolean getBoolean(String key) {
		class_310 ins = class_310.method_1551();
		HudderConfig config = Hudder.config;
		class_746 p = ins.field_1724;
		class_4184 c = ins.field_1773.method_19418();
		return switch (key) {
			
			
			
			/* Generic */
			case "isslime", "is_slime": {
				try {
					yield class_2919.method_12662(p.method_31477() >> 4, p.method_31479() >> 4, ins.method_1576()
							.method_3847(ins.field_1687.method_27983()).method_8412(), 987234911L).method_43048(10) == 0;
				} catch (Exception e) {/* For some reason adding a yield false; here causes runtime errors...*/}
				yield false;
			}
			case "hudhidden": yield ins.field_1690.field_1842;
			case "showdebug": yield ins.method_53526().method_53536();
			case "camera_detached": yield c.method_19331() != p;
			
			
			
			/* GUI */ 
			case "isguiopen": yield ins.field_1755!=null;
			case "ischestopen": yield ins.field_1755 instanceof class_476;
			case "iscraftingtableopen": yield ins.field_1755 instanceof class_479;
			case "ischatopen": yield ins.field_1755 instanceof class_408;
//			No Dialogs
//			case "isdialogopen": yield ins.screen instanceof DialogScreen<?>;
			case "isinventoryopen": yield ins.field_1755 instanceof class_490
					|| ins.field_1755 instanceof class_481;
			
			
			
			/* Player gamemode */
			case "issurvival","is_survival": yield ins.field_1761.method_2920()==class_1934.field_9215;
			case "iscreative","is_creative": yield ins.field_1761.method_2920()==class_1934.field_9220;
			case "isadventure","is_adventure": yield ins.field_1761.method_2920()==class_1934.field_9216;
			case "isspectator","is_spectator": yield ins.field_1761.method_2920()==class_1934.field_9219;
			
			
			
			/* Player movement */
			case "isflying": yield p.method_31549().field_7479;
			case "isgliding": yield p.method_6128();
			case "isclimbing": yield p.method_6101();
			case "iscrawling": yield p.method_20448();
			case "isswimming": yield p.method_5681();
			case "issneaking": yield p.method_5715();
				
			
			
			/* Player information */
			case "isalive": yield p.method_5805();
			case "isblocking": yield p.method_6039();
			case "isfreezing": yield p.method_40071();
			case "isglowing": yield p.method_5851();
			case "isfireimmune": yield p.method_5753();
			case "isonfire": yield p.method_5809();
			case "isonground": yield p.method_24828();
			case "isinvisible": yield p.method_5767();
			case "isdrowning": yield p.method_5799();
			case "iscontrollingmount": yield p.method_49694() != null;
			case "isonmount": yield p.method_5854()!=null;



			/* Mount information */
			case "mount_is_saddled": yield p.method_5854() instanceof class_1496 mob && mob.method_6725();
			case "mount_has_armor": yield p.method_5854() instanceof class_1308 mob && mob.method_56677();
			case "mount_is_tamed": yield p.method_5854() instanceof class_1496 horse && horse.method_6727();
			case "mount_has_chest": yield p.method_5854() instanceof class_1492 horse && horse.method_6703();



			/* Mouse */
			case "mouse_left": yield ins.field_1729.method_1608();
			case "mouse_middle": yield ins.field_1729.method_35707();
			case "mouse_right": yield ins.field_1729.method_1609();
			
			
			
			/* Hudder */
			case "enabled": yield true; //Duh
			case "shadow": yield config.shadow;
			case "showinf3": yield config.showInF3;
			case "javascriptenabled": yield config.javascript;
			case "globalvariablesenabled": yield config.globalVariablesEnabled;
			case "background": yield config.background;
			case "removegui": yield config.removegui;
			case "limitrate": yield config.limitrate;
			default: int keyheld = isKeyHeld(key); yield keyheld==0 ? null : keyheld==2;
		};
	}
}

==> hudder-8.6.0-sources.jar: io/github/ngspace/hudder/data_management/BooleanData.java <==
package io.github.ngspace.hudder.data_management;

import static io.github.ngspace.hudder.data_management.Advanced.isKeyHeld;

import io.github.ngspace.hudder.Hudder;
import io.github.ngspace.hudder.main.config.HudderConfig;
import net.minecraft.class_11473;
import net.minecraft.class_1308;
import net.minecraft.class_1492;
import net.minecraft.class_1496;
import net.minecraft.class_1934;
import net.minecraft.class_2919;
import net.minecraft.class_310;
import net.minecraft.class_408;
import net.minecraft.class_4184;
import net.minecraft.class_476;
import net.minecraft.class_479;
import net.minecraft.class_481;
import net.minecraft.class_490;
import net.minecraft.class_746;

public class BooleanData {private BooleanData(){}
	public static Boolean getBoolean(String key) {
		class_310 ins = class_310.method_1551();
		HudderConfig config = Hudder.config;
		class_746 p = ins.field_1724;
		class_4184 c = ins.field_1773.method_19418();
		return switch (key) {
			
			
			
			/* Generic */
			case "isslime", "is_slime": {
				try {
					yield class_2919.method_12662(p.method_31477() >> 4, p.method_31479() >> 4, ins.method_1576()
							.method_3847(ins.field_1687.method_27983()).method_8412(), 987234911L).method_43048(10) == 0;
				} catch (Exception e) {/* For some reason adding a yield false; here causes runtime errors...*/}
				yield false;
			}
			case "hudhidden": yield ins.field_1690.field_1842;
			case "showdebug": yield ins.method_53526().method_53536();
			case "camera_detached": yield c.method_19331() != p;
			
			
			
			/* GUI */ 
			case "isguiopen": yield ins.field_1755!=null;
			case "ischestopen": yield ins.field_1755 instanceof class_476;
			case "iscraftingtableopen": yield ins.field_1755 instanceof class_479;
			case "ischatopen": yield ins.field_1755 instanceof class_408;
			case "isdialogopen": yield ins.field_1755 instanceof class_11473<?>;
			case "isinventoryopen": yield ins.field_1755 instanceof class_490
					|| ins.field_1755 instanceof class_481;
			
			
			
			/* Player gamemode */
			case "issurvival","is_survival": yield ins.field_1761.method_2920()==class_1934.field_9215;
			case "iscreative","is_creative": yield ins.field_1761.method_2920()==class_1934.field_9220;
			case "isadventure","is_adventure": yield ins.field_1761.method_2920()==class_1934.field_9216;
			case "isspectator","is_spectator": yield ins.field_1761.method_2920()==class_1934.field_9219;
			
			
			
			/* Player movement */
			case "isflying": yield p.method_31549().field_7479;
			case "isgliding": yield p.method_6128();
			case "isclimbing": yield p.method_6101();
			case "iscrawling": yield p.method_20448();
			case "isswimming": yield p.method_5681();
			case "issneaking": yield p.method_5715();
			case "issprinting": yield p.method_5624();
				
			
			
			/* Player information */
			case "isalive": yield p.method_5805();
			case "isblocking": yield p.method_6039();
			case "isfreezing": yield p.method_40071();
			case "isglowing": yield p.method_5851();
			case "isfireimmune": yield p.method_5753();
			case "isonfire": yield p.method_5809();
			case "isonground": yield p.method_24828();
			case "isinvisible": yield p.method_5767();
			case "isdrowning": yield p.method_5799();
			case "iscontrollingmount": yield p.method_49694() != null;
			case "isonmount": yield p.method_5854()!=null;



			/* Mount information */
			case "mount_is_saddled": yield p.method_5854() instanceof class_1308 mob && mob.method_66672();
			case "mount_has_armor": yield p.method_5854() instanceof class_1308 mob && mob.method_56677();
			case "mount_is_tamed": yield p.method_5854() instanceof class_1496 horse && horse.method_6727();
			case "mount_has_chest": yield p.method_5854() instanceof class_1492 horse && horse.method_6703();



			/* Mouse */
			case "mouse_left": yield ins.field_1729.method_1608();
			case "mouse_middle": yield ins.field_1729.method_35707();
			case "mouse_right": yield ins.field_1729.method_1609();
			
			
			
			/* Hudder */
			case "enabled": yield true; //Duh
			case "shadow": yield config.shadow;
			case "showinf3": yield config.showInF3;
			case "javascriptenabled": yield true; // For compatibility
			case "unsafeoperations": yield config.unsafeoperations;
			case "globalvariablesenabled": yield config.globalVariablesEnabled;
			case "background": yield config.background;
			case "removegui": yield config.removegui;
			case "limitrate": yield config.limitrate;
			default: int keyheld = isKeyHeld(key); yield keyheld==0 ? null : keyheld==2;
		};
	}
}
